All of lore.kernel.org
 help / color / mirror / Atom feed
* [PATCH 0/2] iommu/ipmmu-vmsa: Add support for R-Car Gen4
@ 2022-01-25 12:56 ` Yoshihiro Shimoda
  0 siblings, 0 replies; 22+ messages in thread
From: Yoshihiro Shimoda @ 2022-01-25 12:56 UTC (permalink / raw)
  To: joro, will, robh+dt; +Cc: linux-renesas-soc, devicetree, iommu

This patch series is based on renesas-drivers-2022-01-11-v5.16 [1].
Note that we have to prepare the following registers' setting
in a bootloader (U-Boot) because the registers are protected.
Otherwise, data mismatch happened if dmatest with the ipmmu is running.

 => mw eed01500 0xc0000000; mw eed41500 0xc0000000

[1]
https://git.kernel.org/pub/scm/linux/kernel/git/geert/renesas-drivers.git/tag/?h=renesas-drivers-2022-01-11-v5.16


Yoshihiro Shimoda (2):
  dt-bindings: iommu: renesas,ipmmu-vmsa: add r8a779f0 support
  iommu/ipmmu-vmsa: Add support for R-Car Gen4

 .../devicetree/bindings/iommu/renesas,ipmmu-vmsa.yaml  |  4 ++++
 drivers/iommu/ipmmu-vmsa.c                             | 10 +++++++---
 2 files changed, 11 insertions(+), 3 deletions(-)

-- 
2.25.1

_______________________________________________
iommu mailing list
iommu@lists.linux-foundation.org
https://lists.linuxfoundation.org/mailman/listinfo/iommu

^ permalink raw reply	[flat|nested] 22+ messages in thread

* [PATCH 0/2] iommu/ipmmu-vmsa: Add support for R-Car Gen4
@ 2022-01-25 12:56 ` Yoshihiro Shimoda
  0 siblings, 0 replies; 22+ messages in thread
From: Yoshihiro Shimoda @ 2022-01-25 12:56 UTC (permalink / raw)
  To: joro, will, robh+dt
  Cc: iommu, devicetree, linux-renesas-soc, Yoshihiro Shimoda

This patch series is based on renesas-drivers-2022-01-11-v5.16 [1].
Note that we have to prepare the following registers' setting
in a bootloader (U-Boot) because the registers are protected.
Otherwise, data mismatch happened if dmatest with the ipmmu is running.

 => mw eed01500 0xc0000000; mw eed41500 0xc0000000

[1]
https://git.kernel.org/pub/scm/linux/kernel/git/geert/renesas-drivers.git/tag/?h=renesas-drivers-2022-01-11-v5.16


Yoshihiro Shimoda (2):
  dt-bindings: iommu: renesas,ipmmu-vmsa: add r8a779f0 support
  iommu/ipmmu-vmsa: Add support for R-Car Gen4

 .../devicetree/bindings/iommu/renesas,ipmmu-vmsa.yaml  |  4 ++++
 drivers/iommu/ipmmu-vmsa.c                             | 10 +++++++---
 2 files changed, 11 insertions(+), 3 deletions(-)

-- 
2.25.1


^ permalink raw reply	[flat|nested] 22+ messages in thread

* [PATCH 1/2] dt-bindings: iommu: renesas, ipmmu-vmsa: add r8a779f0 support
  2022-01-25 12:56 ` Yoshihiro Shimoda
@ 2022-01-25 12:56   ` Yoshihiro Shimoda
  -1 siblings, 0 replies; 22+ messages in thread
From: Yoshihiro Shimoda @ 2022-01-25 12:56 UTC (permalink / raw)
  To: joro, will, robh+dt; +Cc: linux-renesas-soc, devicetree, iommu

Document the compatible values for the IPMMU-VMSA blocks in
the Renesas R-Car S4-8 (R8A779F0) SoC and R-Car Gen4.

Signed-off-by: Yoshihiro Shimoda <yoshihiro.shimoda.uh@renesas.com>
---
 .../devicetree/bindings/iommu/renesas,ipmmu-vmsa.yaml         | 4 ++++
 1 file changed, 4 insertions(+)

diff --git a/Documentation/devicetree/bindings/iommu/renesas,ipmmu-vmsa.yaml b/Documentation/devicetree/bindings/iommu/renesas,ipmmu-vmsa.yaml
index ce0c715205c6..5159a87f3fa7 100644
--- a/Documentation/devicetree/bindings/iommu/renesas,ipmmu-vmsa.yaml
+++ b/Documentation/devicetree/bindings/iommu/renesas,ipmmu-vmsa.yaml
@@ -44,6 +44,10 @@ properties:
               - renesas,ipmmu-r8a77990 # R-Car E3
               - renesas,ipmmu-r8a77995 # R-Car D3
               - renesas,ipmmu-r8a779a0 # R-Car V3U
+      - items:
+          - enum:
+              - renesas,ipmmu-r8a779f0 # R-Car S4-8
+          - const: renesas,rcar-gen4-ipmmu-vmsa  # R-Car Gen4
 
   reg:
     maxItems: 1
-- 
2.25.1

_______________________________________________
iommu mailing list
iommu@lists.linux-foundation.org
https://lists.linuxfoundation.org/mailman/listinfo/iommu

^ permalink raw reply related	[flat|nested] 22+ messages in thread

* [PATCH 1/2] dt-bindings: iommu: renesas,ipmmu-vmsa: add r8a779f0 support
@ 2022-01-25 12:56   ` Yoshihiro Shimoda
  0 siblings, 0 replies; 22+ messages in thread
From: Yoshihiro Shimoda @ 2022-01-25 12:56 UTC (permalink / raw)
  To: joro, will, robh+dt
  Cc: iommu, devicetree, linux-renesas-soc, Yoshihiro Shimoda

Document the compatible values for the IPMMU-VMSA blocks in
the Renesas R-Car S4-8 (R8A779F0) SoC and R-Car Gen4.

Signed-off-by: Yoshihiro Shimoda <yoshihiro.shimoda.uh@renesas.com>
---
 .../devicetree/bindings/iommu/renesas,ipmmu-vmsa.yaml         | 4 ++++
 1 file changed, 4 insertions(+)

diff --git a/Documentation/devicetree/bindings/iommu/renesas,ipmmu-vmsa.yaml b/Documentation/devicetree/bindings/iommu/renesas,ipmmu-vmsa.yaml
index ce0c715205c6..5159a87f3fa7 100644
--- a/Documentation/devicetree/bindings/iommu/renesas,ipmmu-vmsa.yaml
+++ b/Documentation/devicetree/bindings/iommu/renesas,ipmmu-vmsa.yaml
@@ -44,6 +44,10 @@ properties:
               - renesas,ipmmu-r8a77990 # R-Car E3
               - renesas,ipmmu-r8a77995 # R-Car D3
               - renesas,ipmmu-r8a779a0 # R-Car V3U
+      - items:
+          - enum:
+              - renesas,ipmmu-r8a779f0 # R-Car S4-8
+          - const: renesas,rcar-gen4-ipmmu-vmsa  # R-Car Gen4
 
   reg:
     maxItems: 1
-- 
2.25.1


^ permalink raw reply related	[flat|nested] 22+ messages in thread

* [PATCH 2/2] iommu/ipmmu-vmsa: Add support for R-Car Gen4
  2022-01-25 12:56 ` Yoshihiro Shimoda
@ 2022-01-25 12:56   ` Yoshihiro Shimoda
  -1 siblings, 0 replies; 22+ messages in thread
From: Yoshihiro Shimoda @ 2022-01-25 12:56 UTC (permalink / raw)
  To: joro, will, robh+dt; +Cc: linux-renesas-soc, devicetree, iommu

Add support for R-Car Gen4 like r8a779f0 (R-Car S4-8). The IPMMU
hardware design of r8a779f0 is the same as r8a779a0. So, rename
"r8a779a0" to "rcar_gen4".

Signed-off-by: Yoshihiro Shimoda <yoshihiro.shimoda.uh@renesas.com>
---
 drivers/iommu/ipmmu-vmsa.c | 10 +++++++---
 1 file changed, 7 insertions(+), 3 deletions(-)

diff --git a/drivers/iommu/ipmmu-vmsa.c b/drivers/iommu/ipmmu-vmsa.c
index ca752bdc710f..6c4314c2e9bf 100644
--- a/drivers/iommu/ipmmu-vmsa.c
+++ b/drivers/iommu/ipmmu-vmsa.c
@@ -719,6 +719,7 @@ static int ipmmu_init_platform_device(struct device *dev,
 
 static const struct soc_device_attribute soc_needs_opt_in[] = {
 	{ .family = "R-Car Gen3", },
+	{ .family = "R-Car Gen4", },
 	{ .family = "RZ/G2", },
 	{ /* sentinel */ }
 };
@@ -743,7 +744,7 @@ static bool ipmmu_device_is_allowed(struct device *dev)
 	unsigned int i;
 
 	/*
 	 * R-Car Gen3 and RZ/G2 use the allow list to opt-in devices.
 	 * For Other SoCs, this returns true anyway.
 	 */
 	if (!soc_device_match(soc_needs_opt_in))
@@ -926,7 +927,7 @@ static const struct ipmmu_features ipmmu_features_rcar_gen3 = {
 	.utlb_offset_base = 0,
 };
 
-static const struct ipmmu_features ipmmu_features_r8a779a0 = {
+static const struct ipmmu_features ipmmu_features_rcar_gen4 = {
 	.use_ns_alias_offset = false,
 	.has_cache_leaf_nodes = true,
 	.number_of_contexts = 16,
@@ -982,7 +983,10 @@ static const struct of_device_id ipmmu_of_ids[] = {
 		.data = &ipmmu_features_rcar_gen3,
 	}, {
 		.compatible = "renesas,ipmmu-r8a779a0",
-		.data = &ipmmu_features_r8a779a0,
+		.data = &ipmmu_features_rcar_gen4,
+	}, {
+		.compatible = "renesas,rcar-gen4-ipmmu",
+		.data = &ipmmu_features_rcar_gen4,
 	}, {
 		/* Terminator */
 	},
@@ -743,7 +744,7 @@ static bool ipmmu_device_is_allowed(struct device *dev)
 
 	/*
-	 * R-Car Gen3 and RZ/G2 use the allow list to opt-in devices.
+	 * R-Car Gen3, Gen4 and RZ/G2 use the allow list to opt-in devices.
 	 * For Other SoCs, this returns true anyway.
 	 */
-- 
2.25.1

_______________________________________________
iommu mailing list
iommu@lists.linux-foundation.org
https://lists.linuxfoundation.org/mailman/listinfo/iommu

^ permalink raw reply related	[flat|nested] 22+ messages in thread

* [PATCH 2/2] iommu/ipmmu-vmsa: Add support for R-Car Gen4
@ 2022-01-25 12:56   ` Yoshihiro Shimoda
  0 siblings, 0 replies; 22+ messages in thread
From: Yoshihiro Shimoda @ 2022-01-25 12:56 UTC (permalink / raw)
  To: joro, will, robh+dt
  Cc: iommu, devicetree, linux-renesas-soc, Yoshihiro Shimoda

Add support for R-Car Gen4 like r8a779f0 (R-Car S4-8). The IPMMU
hardware design of r8a779f0 is the same as r8a779a0. So, rename
"r8a779a0" to "rcar_gen4".

Signed-off-by: Yoshihiro Shimoda <yoshihiro.shimoda.uh@renesas.com>
---
 drivers/iommu/ipmmu-vmsa.c | 10 +++++++---
 1 file changed, 7 insertions(+), 3 deletions(-)

diff --git a/drivers/iommu/ipmmu-vmsa.c b/drivers/iommu/ipmmu-vmsa.c
index ca752bdc710f..6c4314c2e9bf 100644
--- a/drivers/iommu/ipmmu-vmsa.c
+++ b/drivers/iommu/ipmmu-vmsa.c
@@ -719,6 +719,7 @@ static int ipmmu_init_platform_device(struct device *dev,
 
 static const struct soc_device_attribute soc_needs_opt_in[] = {
 	{ .family = "R-Car Gen3", },
+	{ .family = "R-Car Gen4", },
 	{ .family = "RZ/G2", },
 	{ /* sentinel */ }
 };
@@ -743,7 +744,7 @@ static bool ipmmu_device_is_allowed(struct device *dev)
 	unsigned int i;
 
 	/*
 	 * R-Car Gen3 and RZ/G2 use the allow list to opt-in devices.
 	 * For Other SoCs, this returns true anyway.
 	 */
 	if (!soc_device_match(soc_needs_opt_in))
@@ -926,7 +927,7 @@ static const struct ipmmu_features ipmmu_features_rcar_gen3 = {
 	.utlb_offset_base = 0,
 };
 
-static const struct ipmmu_features ipmmu_features_r8a779a0 = {
+static const struct ipmmu_features ipmmu_features_rcar_gen4 = {
 	.use_ns_alias_offset = false,
 	.has_cache_leaf_nodes = true,
 	.number_of_contexts = 16,
@@ -982,7 +983,10 @@ static const struct of_device_id ipmmu_of_ids[] = {
 		.data = &ipmmu_features_rcar_gen3,
 	}, {
 		.compatible = "renesas,ipmmu-r8a779a0",
-		.data = &ipmmu_features_r8a779a0,
+		.data = &ipmmu_features_rcar_gen4,
+	}, {
+		.compatible = "renesas,rcar-gen4-ipmmu",
+		.data = &ipmmu_features_rcar_gen4,
 	}, {
 		/* Terminator */
 	},
@@ -743,7 +744,7 @@ static bool ipmmu_device_is_allowed(struct device *dev)
 
 	/*
-	 * R-Car Gen3 and RZ/G2 use the allow list to opt-in devices.
+	 * R-Car Gen3, Gen4 and RZ/G2 use the allow list to opt-in devices.
 	 * For Other SoCs, this returns true anyway.
 	 */
-- 
2.25.1


^ permalink raw reply related	[flat|nested] 22+ messages in thread

* Re: [PATCH 1/2] dt-bindings: iommu: renesas,ipmmu-vmsa: add r8a779f0 support
  2022-01-25 12:56   ` [PATCH 1/2] dt-bindings: iommu: renesas,ipmmu-vmsa: " Yoshihiro Shimoda
@ 2022-01-27 11:05     ` Geert Uytterhoeven
  -1 siblings, 0 replies; 22+ messages in thread
From: Geert Uytterhoeven @ 2022-01-27 11:05 UTC (permalink / raw)
  To: Yoshihiro Shimoda
  Cc: Joerg Roedel, Will Deacon, Rob Herring, Linux IOMMU,
	open list:OPEN FIRMWARE AND FLATTENED DEVICE TREE BINDINGS,
	Linux-Renesas, Laurent Pinchart, Magnus Damm

Hi Shimoda-san,

CC Laurent, Magnus.

On Tue, Jan 25, 2022 at 6:33 PM Yoshihiro Shimoda
<yoshihiro.shimoda.uh@renesas.com> wrote:
> Document the compatible values for the IPMMU-VMSA blocks in
> the Renesas R-Car S4-8 (R8A779F0) SoC and R-Car Gen4.
>
> Signed-off-by: Yoshihiro Shimoda <yoshihiro.shimoda.uh@renesas.com>

Thanks for your patch!

> --- a/Documentation/devicetree/bindings/iommu/renesas,ipmmu-vmsa.yaml
> +++ b/Documentation/devicetree/bindings/iommu/renesas,ipmmu-vmsa.yaml
> @@ -44,6 +44,10 @@ properties:
>                - renesas,ipmmu-r8a77990 # R-Car E3
>                - renesas,ipmmu-r8a77995 # R-Car D3
>                - renesas,ipmmu-r8a779a0 # R-Car V3U
> +      - items:
> +          - enum:
> +              - renesas,ipmmu-r8a779f0 # R-Car S4-8
> +          - const: renesas,rcar-gen4-ipmmu-vmsa  # R-Car Gen4
>

I'm wondering if we need the family-specific fallback.
For R-Car Gen3, we don't have it, and match on (all) the SoC-specific
compatible values instead.
Do you remember why we decided to do it that way?

At least R-Car V3M/V3H/D3 have slight differences in the register bits,
but I don't think that was the reason.

Gr{oetje,eeting}s,

                        Geert

--
Geert Uytterhoeven -- There's lots of Linux beyond ia32 -- geert@linux-m68k.org

In personal conversations with technical people, I call myself a hacker. But
when I'm talking to journalists I just say "programmer" or something like that.
                                -- Linus Torvalds

^ permalink raw reply	[flat|nested] 22+ messages in thread

* Re: [PATCH 1/2] dt-bindings: iommu: renesas, ipmmu-vmsa: add r8a779f0 support
@ 2022-01-27 11:05     ` Geert Uytterhoeven
  0 siblings, 0 replies; 22+ messages in thread
From: Geert Uytterhoeven @ 2022-01-27 11:05 UTC (permalink / raw)
  To: Yoshihiro Shimoda
  Cc: open list:OPEN FIRMWARE AND FLATTENED DEVICE TREE BINDINGS,
	Laurent Pinchart, Magnus Damm, Linux-Renesas, Linux IOMMU,
	Rob Herring, Will Deacon

Hi Shimoda-san,

CC Laurent, Magnus.

On Tue, Jan 25, 2022 at 6:33 PM Yoshihiro Shimoda
<yoshihiro.shimoda.uh@renesas.com> wrote:
> Document the compatible values for the IPMMU-VMSA blocks in
> the Renesas R-Car S4-8 (R8A779F0) SoC and R-Car Gen4.
>
> Signed-off-by: Yoshihiro Shimoda <yoshihiro.shimoda.uh@renesas.com>

Thanks for your patch!

> --- a/Documentation/devicetree/bindings/iommu/renesas,ipmmu-vmsa.yaml
> +++ b/Documentation/devicetree/bindings/iommu/renesas,ipmmu-vmsa.yaml
> @@ -44,6 +44,10 @@ properties:
>                - renesas,ipmmu-r8a77990 # R-Car E3
>                - renesas,ipmmu-r8a77995 # R-Car D3
>                - renesas,ipmmu-r8a779a0 # R-Car V3U
> +      - items:
> +          - enum:
> +              - renesas,ipmmu-r8a779f0 # R-Car S4-8
> +          - const: renesas,rcar-gen4-ipmmu-vmsa  # R-Car Gen4
>

I'm wondering if we need the family-specific fallback.
For R-Car Gen3, we don't have it, and match on (all) the SoC-specific
compatible values instead.
Do you remember why we decided to do it that way?

At least R-Car V3M/V3H/D3 have slight differences in the register bits,
but I don't think that was the reason.

Gr{oetje,eeting}s,

                        Geert

--
Geert Uytterhoeven -- There's lots of Linux beyond ia32 -- geert@linux-m68k.org

In personal conversations with technical people, I call myself a hacker. But
when I'm talking to journalists I just say "programmer" or something like that.
                                -- Linus Torvalds
_______________________________________________
iommu mailing list
iommu@lists.linux-foundation.org
https://lists.linuxfoundation.org/mailman/listinfo/iommu

^ permalink raw reply	[flat|nested] 22+ messages in thread

* Re: [PATCH 1/2] dt-bindings: iommu: renesas,ipmmu-vmsa: add r8a779f0 support
  2022-01-27 11:05     ` [PATCH 1/2] dt-bindings: iommu: renesas, ipmmu-vmsa: " Geert Uytterhoeven
@ 2022-01-27 13:43       ` Laurent Pinchart
  -1 siblings, 0 replies; 22+ messages in thread
From: Laurent Pinchart @ 2022-01-27 13:43 UTC (permalink / raw)
  To: Geert Uytterhoeven
  Cc: Yoshihiro Shimoda, Joerg Roedel, Will Deacon, Rob Herring,
	Linux IOMMU,
	open list:OPEN FIRMWARE AND FLATTENED DEVICE TREE BINDINGS,
	Linux-Renesas, Magnus Damm

Hi Geert,

On Thu, Jan 27, 2022 at 12:05:31PM +0100, Geert Uytterhoeven wrote:
> On Tue, Jan 25, 2022 at 6:33 PM Yoshihiro Shimoda wrote:
> > Document the compatible values for the IPMMU-VMSA blocks in
> > the Renesas R-Car S4-8 (R8A779F0) SoC and R-Car Gen4.
> >
> > Signed-off-by: Yoshihiro Shimoda <yoshihiro.shimoda.uh@renesas.com>
> 
> Thanks for your patch!
> 
> > --- a/Documentation/devicetree/bindings/iommu/renesas,ipmmu-vmsa.yaml
> > +++ b/Documentation/devicetree/bindings/iommu/renesas,ipmmu-vmsa.yaml
> > @@ -44,6 +44,10 @@ properties:
> >                - renesas,ipmmu-r8a77990 # R-Car E3
> >                - renesas,ipmmu-r8a77995 # R-Car D3
> >                - renesas,ipmmu-r8a779a0 # R-Car V3U
> > +      - items:
> > +          - enum:
> > +              - renesas,ipmmu-r8a779f0 # R-Car S4-8
> > +          - const: renesas,rcar-gen4-ipmmu-vmsa  # R-Car Gen4
> 
> I'm wondering if we need the family-specific fallback.
> For R-Car Gen3, we don't have it, and match on (all) the SoC-specific
> compatible values instead.
> Do you remember why we decided to do it that way?

I'm afraid I don't. You know my usual opinion of SoC-specific compatible
strings :-)

> At least R-Car V3M/V3H/D3 have slight differences in the register bits,
> but I don't think that was the reason.

-- 
Regards,

Laurent Pinchart

^ permalink raw reply	[flat|nested] 22+ messages in thread

* Re: [PATCH 1/2] dt-bindings: iommu: renesas, ipmmu-vmsa: add r8a779f0 support
@ 2022-01-27 13:43       ` Laurent Pinchart
  0 siblings, 0 replies; 22+ messages in thread
From: Laurent Pinchart @ 2022-01-27 13:43 UTC (permalink / raw)
  To: Geert Uytterhoeven
  Cc: open list:OPEN FIRMWARE AND FLATTENED DEVICE TREE BINDINGS,
	Magnus Damm, Linux-Renesas, Linux IOMMU, Rob Herring,
	Will Deacon

Hi Geert,

On Thu, Jan 27, 2022 at 12:05:31PM +0100, Geert Uytterhoeven wrote:
> On Tue, Jan 25, 2022 at 6:33 PM Yoshihiro Shimoda wrote:
> > Document the compatible values for the IPMMU-VMSA blocks in
> > the Renesas R-Car S4-8 (R8A779F0) SoC and R-Car Gen4.
> >
> > Signed-off-by: Yoshihiro Shimoda <yoshihiro.shimoda.uh@renesas.com>
> 
> Thanks for your patch!
> 
> > --- a/Documentation/devicetree/bindings/iommu/renesas,ipmmu-vmsa.yaml
> > +++ b/Documentation/devicetree/bindings/iommu/renesas,ipmmu-vmsa.yaml
> > @@ -44,6 +44,10 @@ properties:
> >                - renesas,ipmmu-r8a77990 # R-Car E3
> >                - renesas,ipmmu-r8a77995 # R-Car D3
> >                - renesas,ipmmu-r8a779a0 # R-Car V3U
> > +      - items:
> > +          - enum:
> > +              - renesas,ipmmu-r8a779f0 # R-Car S4-8
> > +          - const: renesas,rcar-gen4-ipmmu-vmsa  # R-Car Gen4
> 
> I'm wondering if we need the family-specific fallback.
> For R-Car Gen3, we don't have it, and match on (all) the SoC-specific
> compatible values instead.
> Do you remember why we decided to do it that way?

I'm afraid I don't. You know my usual opinion of SoC-specific compatible
strings :-)

> At least R-Car V3M/V3H/D3 have slight differences in the register bits,
> but I don't think that was the reason.

-- 
Regards,

Laurent Pinchart
_______________________________________________
iommu mailing list
iommu@lists.linux-foundation.org
https://lists.linuxfoundation.org/mailman/listinfo/iommu

^ permalink raw reply	[flat|nested] 22+ messages in thread

* RE: [PATCH 1/2] dt-bindings: iommu: renesas,ipmmu-vmsa: add r8a779f0 support
  2022-01-27 11:05     ` [PATCH 1/2] dt-bindings: iommu: renesas, ipmmu-vmsa: " Geert Uytterhoeven
@ 2022-01-28  0:09       ` Yoshihiro Shimoda
  -1 siblings, 0 replies; 22+ messages in thread
From: Yoshihiro Shimoda @ 2022-01-28  0:09 UTC (permalink / raw)
  To: Geert Uytterhoeven
  Cc: Joerg Roedel, Will Deacon, Rob Herring, Linux IOMMU,
	open list:OPEN FIRMWARE AND FLATTENED DEVICE TREE BINDINGS,
	Linux-Renesas, Laurent Pinchart, Magnus Damm

Hi Geert-san,

Thank you for your review!

> From: Geert Uytterhoeven, Sent: Thursday, January 27, 2022 8:06 PM
> 
> Hi Shimoda-san,
> 
> CC Laurent, Magnus.
> 
> On Tue, Jan 25, 2022 at 6:33 PM Yoshihiro Shimoda
> <yoshihiro.shimoda.uh@renesas.com> wrote:
> > Document the compatible values for the IPMMU-VMSA blocks in
> > the Renesas R-Car S4-8 (R8A779F0) SoC and R-Car Gen4.
> >
> > Signed-off-by: Yoshihiro Shimoda <yoshihiro.shimoda.uh@renesas.com>
> 
> Thanks for your patch!
> 
> > --- a/Documentation/devicetree/bindings/iommu/renesas,ipmmu-vmsa.yaml
> > +++ b/Documentation/devicetree/bindings/iommu/renesas,ipmmu-vmsa.yaml
> > @@ -44,6 +44,10 @@ properties:
> >                - renesas,ipmmu-r8a77990 # R-Car E3
> >                - renesas,ipmmu-r8a77995 # R-Car D3
> >                - renesas,ipmmu-r8a779a0 # R-Car V3U
> > +      - items:
> > +          - enum:
> > +              - renesas,ipmmu-r8a779f0 # R-Car S4-8
> > +          - const: renesas,rcar-gen4-ipmmu-vmsa  # R-Car Gen4
> >
> 
> I'm wondering if we need the family-specific fallback.
> For R-Car Gen3, we don't have it, and match on (all) the SoC-specific
> compatible values instead.
> Do you remember why we decided to do it that way?
> 
> At least R-Car V3M/V3H/D3 have slight differences in the register bits,
> but I don't think that was the reason.

I don't remember why... Maybe, we had never discussed this topic?
I searched this topic a little on the ML archive, but I could not find it...

Since upcoming R-Car Gen4 SoC's IPMMU is the same specification with r8a779f0,
I believe renesas,rcar-gen4-ipmmu-vmsa is helpful to support it.

Best regards,
Yoshihiro Shimoda

> 
> Gr{oetje,eeting}s,
> 
>                         Geert
> 
> --
> Geert Uytterhoeven -- There's lots of Linux beyond ia32 -- geert@linux-m68k.org
> 
> In personal conversations with technical people, I call myself a hacker. But
> when I'm talking to journalists I just say "programmer" or something like that.
>                                 -- Linus Torvalds

^ permalink raw reply	[flat|nested] 22+ messages in thread

* RE: [PATCH 1/2] dt-bindings: iommu: renesas, ipmmu-vmsa: add r8a779f0 support
@ 2022-01-28  0:09       ` Yoshihiro Shimoda
  0 siblings, 0 replies; 22+ messages in thread
From: Yoshihiro Shimoda @ 2022-01-28  0:09 UTC (permalink / raw)
  To: Geert Uytterhoeven
  Cc: open list:OPEN FIRMWARE AND FLATTENED DEVICE TREE BINDINGS,
	Laurent Pinchart, Magnus Damm, Linux-Renesas, Linux IOMMU,
	Rob Herring, Will Deacon

Hi Geert-san,

Thank you for your review!

> From: Geert Uytterhoeven, Sent: Thursday, January 27, 2022 8:06 PM
> 
> Hi Shimoda-san,
> 
> CC Laurent, Magnus.
> 
> On Tue, Jan 25, 2022 at 6:33 PM Yoshihiro Shimoda
> <yoshihiro.shimoda.uh@renesas.com> wrote:
> > Document the compatible values for the IPMMU-VMSA blocks in
> > the Renesas R-Car S4-8 (R8A779F0) SoC and R-Car Gen4.
> >
> > Signed-off-by: Yoshihiro Shimoda <yoshihiro.shimoda.uh@renesas.com>
> 
> Thanks for your patch!
> 
> > --- a/Documentation/devicetree/bindings/iommu/renesas,ipmmu-vmsa.yaml
> > +++ b/Documentation/devicetree/bindings/iommu/renesas,ipmmu-vmsa.yaml
> > @@ -44,6 +44,10 @@ properties:
> >                - renesas,ipmmu-r8a77990 # R-Car E3
> >                - renesas,ipmmu-r8a77995 # R-Car D3
> >                - renesas,ipmmu-r8a779a0 # R-Car V3U
> > +      - items:
> > +          - enum:
> > +              - renesas,ipmmu-r8a779f0 # R-Car S4-8
> > +          - const: renesas,rcar-gen4-ipmmu-vmsa  # R-Car Gen4
> >
> 
> I'm wondering if we need the family-specific fallback.
> For R-Car Gen3, we don't have it, and match on (all) the SoC-specific
> compatible values instead.
> Do you remember why we decided to do it that way?
> 
> At least R-Car V3M/V3H/D3 have slight differences in the register bits,
> but I don't think that was the reason.

I don't remember why... Maybe, we had never discussed this topic?
I searched this topic a little on the ML archive, but I could not find it...

Since upcoming R-Car Gen4 SoC's IPMMU is the same specification with r8a779f0,
I believe renesas,rcar-gen4-ipmmu-vmsa is helpful to support it.

Best regards,
Yoshihiro Shimoda

> 
> Gr{oetje,eeting}s,
> 
>                         Geert
> 
> --
> Geert Uytterhoeven -- There's lots of Linux beyond ia32 -- geert@linux-m68k.org
> 
> In personal conversations with technical people, I call myself a hacker. But
> when I'm talking to journalists I just say "programmer" or something like that.
>                                 -- Linus Torvalds
_______________________________________________
iommu mailing list
iommu@lists.linux-foundation.org
https://lists.linuxfoundation.org/mailman/listinfo/iommu

^ permalink raw reply	[flat|nested] 22+ messages in thread

* Re: [PATCH 2/2] iommu/ipmmu-vmsa: Add support for R-Car Gen4
  2022-01-25 12:56   ` Yoshihiro Shimoda
@ 2022-02-02  9:23     ` Geert Uytterhoeven
  -1 siblings, 0 replies; 22+ messages in thread
From: Geert Uytterhoeven @ 2022-02-02  9:23 UTC (permalink / raw)
  To: Yoshihiro Shimoda
  Cc: Joerg Roedel, Will Deacon, Rob Herring, Linux IOMMU,
	open list:OPEN FIRMWARE AND FLATTENED DEVICE TREE BINDINGS,
	Linux-Renesas

Hi Shimoda-san,

On Tue, Jan 25, 2022 at 6:36 PM Yoshihiro Shimoda
<yoshihiro.shimoda.uh@renesas.com> wrote:
> Add support for R-Car Gen4 like r8a779f0 (R-Car S4-8). The IPMMU
> hardware design of r8a779f0 is the same as r8a779a0. So, rename
> "r8a779a0" to "rcar_gen4".
>
> Signed-off-by: Yoshihiro Shimoda <yoshihiro.shimoda.uh@renesas.com>

Thanks for your patch!

> --- a/drivers/iommu/ipmmu-vmsa.c
> +++ b/drivers/iommu/ipmmu-vmsa.c

> @@ -743,7 +744,7 @@ static bool ipmmu_device_is_allowed(struct device *dev)
>         unsigned int i;
>
>         /*
> -        * R-Car Gen3 and RZ/G2 use the allow list to opt-in devices.
> +        * R-Car Gen3, Gen4 and RZ/G2 use the allow list to opt-in devices.
>          * For Other SoCs, this returns true anyway.
>          */
>         if (!soc_device_match(soc_needs_opt_in))

There are a few more references to "Gen3" that can be extended.

Gr{oetje,eeting}s,

                        Geert

--
Geert Uytterhoeven -- There's lots of Linux beyond ia32 -- geert@linux-m68k.org

In personal conversations with technical people, I call myself a hacker. But
when I'm talking to journalists I just say "programmer" or something like that.
                                -- Linus Torvalds

^ permalink raw reply	[flat|nested] 22+ messages in thread

* Re: [PATCH 2/2] iommu/ipmmu-vmsa: Add support for R-Car Gen4
@ 2022-02-02  9:23     ` Geert Uytterhoeven
  0 siblings, 0 replies; 22+ messages in thread
From: Geert Uytterhoeven @ 2022-02-02  9:23 UTC (permalink / raw)
  To: Yoshihiro Shimoda
  Cc: open list:OPEN FIRMWARE AND FLATTENED DEVICE TREE BINDINGS,
	Linux-Renesas, Linux IOMMU, Rob Herring, Will Deacon

Hi Shimoda-san,

On Tue, Jan 25, 2022 at 6:36 PM Yoshihiro Shimoda
<yoshihiro.shimoda.uh@renesas.com> wrote:
> Add support for R-Car Gen4 like r8a779f0 (R-Car S4-8). The IPMMU
> hardware design of r8a779f0 is the same as r8a779a0. So, rename
> "r8a779a0" to "rcar_gen4".
>
> Signed-off-by: Yoshihiro Shimoda <yoshihiro.shimoda.uh@renesas.com>

Thanks for your patch!

> --- a/drivers/iommu/ipmmu-vmsa.c
> +++ b/drivers/iommu/ipmmu-vmsa.c

> @@ -743,7 +744,7 @@ static bool ipmmu_device_is_allowed(struct device *dev)
>         unsigned int i;
>
>         /*
> -        * R-Car Gen3 and RZ/G2 use the allow list to opt-in devices.
> +        * R-Car Gen3, Gen4 and RZ/G2 use the allow list to opt-in devices.
>          * For Other SoCs, this returns true anyway.
>          */
>         if (!soc_device_match(soc_needs_opt_in))

There are a few more references to "Gen3" that can be extended.

Gr{oetje,eeting}s,

                        Geert

--
Geert Uytterhoeven -- There's lots of Linux beyond ia32 -- geert@linux-m68k.org

In personal conversations with technical people, I call myself a hacker. But
when I'm talking to journalists I just say "programmer" or something like that.
                                -- Linus Torvalds
_______________________________________________
iommu mailing list
iommu@lists.linux-foundation.org
https://lists.linuxfoundation.org/mailman/listinfo/iommu

^ permalink raw reply	[flat|nested] 22+ messages in thread

* Re: [PATCH 1/2] dt-bindings: iommu: renesas,ipmmu-vmsa: add r8a779f0 support
  2022-01-28  0:09       ` [PATCH 1/2] dt-bindings: iommu: renesas, ipmmu-vmsa: " Yoshihiro Shimoda
@ 2022-02-02  9:36         ` Geert Uytterhoeven
  -1 siblings, 0 replies; 22+ messages in thread
From: Geert Uytterhoeven @ 2022-02-02  9:36 UTC (permalink / raw)
  To: Yoshihiro Shimoda
  Cc: Joerg Roedel, Will Deacon, Rob Herring, Linux IOMMU,
	open list:OPEN FIRMWARE AND FLATTENED DEVICE TREE BINDINGS,
	Linux-Renesas, Laurent Pinchart, Magnus Damm

Hi Shimoda-san,

On Fri, Jan 28, 2022 at 1:09 AM Yoshihiro Shimoda
<yoshihiro.shimoda.uh@renesas.com> wrote:
> > From: Geert Uytterhoeven, Sent: Thursday, January 27, 2022 8:06 PM
>
> > On Tue, Jan 25, 2022 at 6:33 PM Yoshihiro Shimoda
> > <yoshihiro.shimoda.uh@renesas.com> wrote:
> > > Document the compatible values for the IPMMU-VMSA blocks in
> > > the Renesas R-Car S4-8 (R8A779F0) SoC and R-Car Gen4.
> > >
> > > Signed-off-by: Yoshihiro Shimoda <yoshihiro.shimoda.uh@renesas.com>

> > > --- a/Documentation/devicetree/bindings/iommu/renesas,ipmmu-vmsa.yaml
> > > +++ b/Documentation/devicetree/bindings/iommu/renesas,ipmmu-vmsa.yaml
> > > @@ -44,6 +44,10 @@ properties:
> > >                - renesas,ipmmu-r8a77990 # R-Car E3
> > >                - renesas,ipmmu-r8a77995 # R-Car D3
> > >                - renesas,ipmmu-r8a779a0 # R-Car V3U
> > > +      - items:
> > > +          - enum:
> > > +              - renesas,ipmmu-r8a779f0 # R-Car S4-8
> > > +          - const: renesas,rcar-gen4-ipmmu-vmsa  # R-Car Gen4
> > >
> >
> > I'm wondering if we need the family-specific fallback.
> > For R-Car Gen3, we don't have it, and match on (all) the SoC-specific
> > compatible values instead.
> > Do you remember why we decided to do it that way?
> >
> > At least R-Car V3M/V3H/D3 have slight differences in the register bits,
> > but I don't think that was the reason.
>
> I don't remember why... Maybe, we had never discussed this topic?
> I searched this topic a little on the ML archive, but I could not find it...

Indeed. I also couldn't find a discussion, and most IPMMUs on R-Car
Gen3 SoCs are identical (although there are differences in parts we
don't use in the driver). The IPMMUs in early R-Car Gen3 SoCs also had
issues, so that's probably why we never went with a family-specific
compatible value. And adding it now wouldn't gain us much.

> Since upcoming R-Car Gen4 SoC's IPMMU is the same specification with r8a779f0,
> I believe renesas,rcar-gen4-ipmmu-vmsa is helpful to support it.

Agreed.
Reviewed-by: Geert Uytterhoeven <geert+renesas@glider.be>

Gr{oetje,eeting}s,

                        Geert

--
Geert Uytterhoeven -- There's lots of Linux beyond ia32 -- geert@linux-m68k.org

In personal conversations with technical people, I call myself a hacker. But
when I'm talking to journalists I just say "programmer" or something like that.
                                -- Linus Torvalds

^ permalink raw reply	[flat|nested] 22+ messages in thread

* Re: [PATCH 1/2] dt-bindings: iommu: renesas, ipmmu-vmsa: add r8a779f0 support
@ 2022-02-02  9:36         ` Geert Uytterhoeven
  0 siblings, 0 replies; 22+ messages in thread
From: Geert Uytterhoeven @ 2022-02-02  9:36 UTC (permalink / raw)
  To: Yoshihiro Shimoda
  Cc: open list:OPEN FIRMWARE AND FLATTENED DEVICE TREE BINDINGS,
	Laurent Pinchart, Magnus Damm, Linux-Renesas, Linux IOMMU,
	Rob Herring, Will Deacon

Hi Shimoda-san,

On Fri, Jan 28, 2022 at 1:09 AM Yoshihiro Shimoda
<yoshihiro.shimoda.uh@renesas.com> wrote:
> > From: Geert Uytterhoeven, Sent: Thursday, January 27, 2022 8:06 PM
>
> > On Tue, Jan 25, 2022 at 6:33 PM Yoshihiro Shimoda
> > <yoshihiro.shimoda.uh@renesas.com> wrote:
> > > Document the compatible values for the IPMMU-VMSA blocks in
> > > the Renesas R-Car S4-8 (R8A779F0) SoC and R-Car Gen4.
> > >
> > > Signed-off-by: Yoshihiro Shimoda <yoshihiro.shimoda.uh@renesas.com>

> > > --- a/Documentation/devicetree/bindings/iommu/renesas,ipmmu-vmsa.yaml
> > > +++ b/Documentation/devicetree/bindings/iommu/renesas,ipmmu-vmsa.yaml
> > > @@ -44,6 +44,10 @@ properties:
> > >                - renesas,ipmmu-r8a77990 # R-Car E3
> > >                - renesas,ipmmu-r8a77995 # R-Car D3
> > >                - renesas,ipmmu-r8a779a0 # R-Car V3U
> > > +      - items:
> > > +          - enum:
> > > +              - renesas,ipmmu-r8a779f0 # R-Car S4-8
> > > +          - const: renesas,rcar-gen4-ipmmu-vmsa  # R-Car Gen4
> > >
> >
> > I'm wondering if we need the family-specific fallback.
> > For R-Car Gen3, we don't have it, and match on (all) the SoC-specific
> > compatible values instead.
> > Do you remember why we decided to do it that way?
> >
> > At least R-Car V3M/V3H/D3 have slight differences in the register bits,
> > but I don't think that was the reason.
>
> I don't remember why... Maybe, we had never discussed this topic?
> I searched this topic a little on the ML archive, but I could not find it...

Indeed. I also couldn't find a discussion, and most IPMMUs on R-Car
Gen3 SoCs are identical (although there are differences in parts we
don't use in the driver). The IPMMUs in early R-Car Gen3 SoCs also had
issues, so that's probably why we never went with a family-specific
compatible value. And adding it now wouldn't gain us much.

> Since upcoming R-Car Gen4 SoC's IPMMU is the same specification with r8a779f0,
> I believe renesas,rcar-gen4-ipmmu-vmsa is helpful to support it.

Agreed.
Reviewed-by: Geert Uytterhoeven <geert+renesas@glider.be>

Gr{oetje,eeting}s,

                        Geert

--
Geert Uytterhoeven -- There's lots of Linux beyond ia32 -- geert@linux-m68k.org

In personal conversations with technical people, I call myself a hacker. But
when I'm talking to journalists I just say "programmer" or something like that.
                                -- Linus Torvalds
_______________________________________________
iommu mailing list
iommu@lists.linux-foundation.org
https://lists.linuxfoundation.org/mailman/listinfo/iommu

^ permalink raw reply	[flat|nested] 22+ messages in thread

* RE: [PATCH 2/2] iommu/ipmmu-vmsa: Add support for R-Car Gen4
  2022-02-02  9:23     ` Geert Uytterhoeven
@ 2022-02-02 10:48       ` Yoshihiro Shimoda
  -1 siblings, 0 replies; 22+ messages in thread
From: Yoshihiro Shimoda @ 2022-02-02 10:48 UTC (permalink / raw)
  To: Geert Uytterhoeven
  Cc: Joerg Roedel, Will Deacon, Rob Herring, Linux IOMMU,
	open list:OPEN FIRMWARE AND FLATTENED DEVICE TREE BINDINGS,
	Linux-Renesas

Hi Geert-san,

Thank you for your review!

> From: Geert Uytterhoeven, Sent: Wednesday, February 2, 2022 6:24 PM
> 
> Hi Shimoda-san,
> 
> On Tue, Jan 25, 2022 at 6:36 PM Yoshihiro Shimoda
> <yoshihiro.shimoda.uh@renesas.com> wrote:
> > Add support for R-Car Gen4 like r8a779f0 (R-Car S4-8). The IPMMU
> > hardware design of r8a779f0 is the same as r8a779a0. So, rename
> > "r8a779a0" to "rcar_gen4".
> >
> > Signed-off-by: Yoshihiro Shimoda <yoshihiro.shimoda.uh@renesas.com>
> 
> Thanks for your patch!
> 
> > --- a/drivers/iommu/ipmmu-vmsa.c
> > +++ b/drivers/iommu/ipmmu-vmsa.c
> 
> > @@ -743,7 +744,7 @@ static bool ipmmu_device_is_allowed(struct device *dev)
> >         unsigned int i;
> >
> >         /*
> > -        * R-Car Gen3 and RZ/G2 use the allow list to opt-in devices.
> > +        * R-Car Gen3, Gen4 and RZ/G2 use the allow list to opt-in devices.
> >          * For Other SoCs, this returns true anyway.
> >          */
> >         if (!soc_device_match(soc_needs_opt_in))
> 
> There are a few more references to "Gen3" that can be extended.

I'm afraid, but I could not understand this mean.

Best regards,
Yoshihiro Shimoda

> Gr{oetje,eeting}s,
> 
>                         Geert
> 
> --
> Geert Uytterhoeven -- There's lots of Linux beyond ia32 -- geert@linux-m68k.org
> 
> In personal conversations with technical people, I call myself a hacker. But
> when I'm talking to journalists I just say "programmer" or something like that.
>                                 -- Linus Torvalds

^ permalink raw reply	[flat|nested] 22+ messages in thread

* RE: [PATCH 2/2] iommu/ipmmu-vmsa: Add support for R-Car Gen4
@ 2022-02-02 10:48       ` Yoshihiro Shimoda
  0 siblings, 0 replies; 22+ messages in thread
From: Yoshihiro Shimoda @ 2022-02-02 10:48 UTC (permalink / raw)
  To: Geert Uytterhoeven
  Cc: open list:OPEN FIRMWARE AND FLATTENED DEVICE TREE BINDINGS,
	Linux-Renesas, Linux IOMMU, Rob Herring, Will Deacon

Hi Geert-san,

Thank you for your review!

> From: Geert Uytterhoeven, Sent: Wednesday, February 2, 2022 6:24 PM
> 
> Hi Shimoda-san,
> 
> On Tue, Jan 25, 2022 at 6:36 PM Yoshihiro Shimoda
> <yoshihiro.shimoda.uh@renesas.com> wrote:
> > Add support for R-Car Gen4 like r8a779f0 (R-Car S4-8). The IPMMU
> > hardware design of r8a779f0 is the same as r8a779a0. So, rename
> > "r8a779a0" to "rcar_gen4".
> >
> > Signed-off-by: Yoshihiro Shimoda <yoshihiro.shimoda.uh@renesas.com>
> 
> Thanks for your patch!
> 
> > --- a/drivers/iommu/ipmmu-vmsa.c
> > +++ b/drivers/iommu/ipmmu-vmsa.c
> 
> > @@ -743,7 +744,7 @@ static bool ipmmu_device_is_allowed(struct device *dev)
> >         unsigned int i;
> >
> >         /*
> > -        * R-Car Gen3 and RZ/G2 use the allow list to opt-in devices.
> > +        * R-Car Gen3, Gen4 and RZ/G2 use the allow list to opt-in devices.
> >          * For Other SoCs, this returns true anyway.
> >          */
> >         if (!soc_device_match(soc_needs_opt_in))
> 
> There are a few more references to "Gen3" that can be extended.

I'm afraid, but I could not understand this mean.

Best regards,
Yoshihiro Shimoda

> Gr{oetje,eeting}s,
> 
>                         Geert
> 
> --
> Geert Uytterhoeven -- There's lots of Linux beyond ia32 -- geert@linux-m68k.org
> 
> In personal conversations with technical people, I call myself a hacker. But
> when I'm talking to journalists I just say "programmer" or something like that.
>                                 -- Linus Torvalds
_______________________________________________
iommu mailing list
iommu@lists.linux-foundation.org
https://lists.linuxfoundation.org/mailman/listinfo/iommu

^ permalink raw reply	[flat|nested] 22+ messages in thread

* Re: [PATCH 2/2] iommu/ipmmu-vmsa: Add support for R-Car Gen4
  2022-02-02 10:48       ` Yoshihiro Shimoda
@ 2022-02-02 11:07         ` Geert Uytterhoeven
  -1 siblings, 0 replies; 22+ messages in thread
From: Geert Uytterhoeven @ 2022-02-02 11:07 UTC (permalink / raw)
  To: Yoshihiro Shimoda
  Cc: Joerg Roedel, Will Deacon, Rob Herring, Linux IOMMU,
	open list:OPEN FIRMWARE AND FLATTENED DEVICE TREE BINDINGS,
	Linux-Renesas

Hi Shimoda-san,

On Wed, Feb 2, 2022 at 11:48 AM Yoshihiro Shimoda
<yoshihiro.shimoda.uh@renesas.com> wrote:
> > From: Geert Uytterhoeven, Sent: Wednesday, February 2, 2022 6:24 PM
> > On Tue, Jan 25, 2022 at 6:36 PM Yoshihiro Shimoda
> > <yoshihiro.shimoda.uh@renesas.com> wrote:
> > > Add support for R-Car Gen4 like r8a779f0 (R-Car S4-8). The IPMMU
> > > hardware design of r8a779f0 is the same as r8a779a0. So, rename
> > > "r8a779a0" to "rcar_gen4".
> > >
> > > Signed-off-by: Yoshihiro Shimoda <yoshihiro.shimoda.uh@renesas.com>
> >
> > Thanks for your patch!
> >
> > > --- a/drivers/iommu/ipmmu-vmsa.c
> > > +++ b/drivers/iommu/ipmmu-vmsa.c
> >
> > > @@ -743,7 +744,7 @@ static bool ipmmu_device_is_allowed(struct device *dev)
> > >         unsigned int i;
> > >
> > >         /*
> > > -        * R-Car Gen3 and RZ/G2 use the allow list to opt-in devices.
> > > +        * R-Car Gen3, Gen4 and RZ/G2 use the allow list to opt-in devices.
> > >          * For Other SoCs, this returns true anyway.
> > >          */
> > >         if (!soc_device_match(soc_needs_opt_in))
> >
> > There are a few more references to "Gen3" that can be extended.
>
> I'm afraid, but I could not understand this mean.

I'm sorry. I mean comments that currently say "Gen3", while they are
applicable to R-Car Gen4, too. I think it would be good to update them
to "Gen3/4".

Gr{oetje,eeting}s,

                        Geert

--
Geert Uytterhoeven -- There's lots of Linux beyond ia32 -- geert@linux-m68k.org

In personal conversations with technical people, I call myself a hacker. But
when I'm talking to journalists I just say "programmer" or something like that.
                                -- Linus Torvalds

^ permalink raw reply	[flat|nested] 22+ messages in thread

* Re: [PATCH 2/2] iommu/ipmmu-vmsa: Add support for R-Car Gen4
@ 2022-02-02 11:07         ` Geert Uytterhoeven
  0 siblings, 0 replies; 22+ messages in thread
From: Geert Uytterhoeven @ 2022-02-02 11:07 UTC (permalink / raw)
  To: Yoshihiro Shimoda
  Cc: open list:OPEN FIRMWARE AND FLATTENED DEVICE TREE BINDINGS,
	Linux-Renesas, Linux IOMMU, Rob Herring, Will Deacon

Hi Shimoda-san,

On Wed, Feb 2, 2022 at 11:48 AM Yoshihiro Shimoda
<yoshihiro.shimoda.uh@renesas.com> wrote:
> > From: Geert Uytterhoeven, Sent: Wednesday, February 2, 2022 6:24 PM
> > On Tue, Jan 25, 2022 at 6:36 PM Yoshihiro Shimoda
> > <yoshihiro.shimoda.uh@renesas.com> wrote:
> > > Add support for R-Car Gen4 like r8a779f0 (R-Car S4-8). The IPMMU
> > > hardware design of r8a779f0 is the same as r8a779a0. So, rename
> > > "r8a779a0" to "rcar_gen4".
> > >
> > > Signed-off-by: Yoshihiro Shimoda <yoshihiro.shimoda.uh@renesas.com>
> >
> > Thanks for your patch!
> >
> > > --- a/drivers/iommu/ipmmu-vmsa.c
> > > +++ b/drivers/iommu/ipmmu-vmsa.c
> >
> > > @@ -743,7 +744,7 @@ static bool ipmmu_device_is_allowed(struct device *dev)
> > >         unsigned int i;
> > >
> > >         /*
> > > -        * R-Car Gen3 and RZ/G2 use the allow list to opt-in devices.
> > > +        * R-Car Gen3, Gen4 and RZ/G2 use the allow list to opt-in devices.
> > >          * For Other SoCs, this returns true anyway.
> > >          */
> > >         if (!soc_device_match(soc_needs_opt_in))
> >
> > There are a few more references to "Gen3" that can be extended.
>
> I'm afraid, but I could not understand this mean.

I'm sorry. I mean comments that currently say "Gen3", while they are
applicable to R-Car Gen4, too. I think it would be good to update them
to "Gen3/4".

Gr{oetje,eeting}s,

                        Geert

--
Geert Uytterhoeven -- There's lots of Linux beyond ia32 -- geert@linux-m68k.org

In personal conversations with technical people, I call myself a hacker. But
when I'm talking to journalists I just say "programmer" or something like that.
                                -- Linus Torvalds
_______________________________________________
iommu mailing list
iommu@lists.linux-foundation.org
https://lists.linuxfoundation.org/mailman/listinfo/iommu

^ permalink raw reply	[flat|nested] 22+ messages in thread

* RE: [PATCH 2/2] iommu/ipmmu-vmsa: Add support for R-Car Gen4
  2022-02-02 11:07         ` Geert Uytterhoeven
@ 2022-02-03  6:54           ` Yoshihiro Shimoda
  -1 siblings, 0 replies; 22+ messages in thread
From: Yoshihiro Shimoda @ 2022-02-03  6:54 UTC (permalink / raw)
  To: Geert Uytterhoeven
  Cc: Joerg Roedel, Will Deacon, Rob Herring, Linux IOMMU,
	open list:OPEN FIRMWARE AND FLATTENED DEVICE TREE BINDINGS,
	Linux-Renesas

Hi Geert-san,

> From: Geert Uytterhoeven, Sent: Wednesday, February 2, 2022 8:07 PM
> 
> Hi Shimoda-san,
> 
> On Wed, Feb 2, 2022 at 11:48 AM Yoshihiro Shimoda
> <yoshihiro.shimoda.uh@renesas.com> wrote:
> > > From: Geert Uytterhoeven, Sent: Wednesday, February 2, 2022 6:24 PM
> > > On Tue, Jan 25, 2022 at 6:36 PM Yoshihiro Shimoda
> > > <yoshihiro.shimoda.uh@renesas.com> wrote:
> > > > Add support for R-Car Gen4 like r8a779f0 (R-Car S4-8). The IPMMU
> > > > hardware design of r8a779f0 is the same as r8a779a0. So, rename
> > > > "r8a779a0" to "rcar_gen4".
> > > >
> > > > Signed-off-by: Yoshihiro Shimoda <yoshihiro.shimoda.uh@renesas.com>
> > >
> > > Thanks for your patch!
> > >
> > > > --- a/drivers/iommu/ipmmu-vmsa.c
> > > > +++ b/drivers/iommu/ipmmu-vmsa.c
> > >
> > > > @@ -743,7 +744,7 @@ static bool ipmmu_device_is_allowed(struct device *dev)
> > > >         unsigned int i;
> > > >
> > > >         /*
> > > > -        * R-Car Gen3 and RZ/G2 use the allow list to opt-in devices.
> > > > +        * R-Car Gen3, Gen4 and RZ/G2 use the allow list to opt-in devices.
> > > >          * For Other SoCs, this returns true anyway.
> > > >          */
> > > >         if (!soc_device_match(soc_needs_opt_in))
> > >
> > > There are a few more references to "Gen3" that can be extended.
> >
> > I'm afraid, but I could not understand this mean.
> 
> I'm sorry. I mean comments that currently say "Gen3", while they are
> applicable to R-Car Gen4, too. I think it would be good to update them
> to "Gen3/4".

Thank you. I understood it. So, I'll fix it in v2.

Best regards,
Yoshihiro Shimoda

> Gr{oetje,eeting}s,
> 
>                         Geert
> 
> --
> Geert Uytterhoeven -- There's lots of Linux beyond ia32 -- geert@linux-m68k.org
> 
> In personal conversations with technical people, I call myself a hacker. But
> when I'm talking to journalists I just say "programmer" or something like that.
>                                 -- Linus Torvalds

^ permalink raw reply	[flat|nested] 22+ messages in thread

* RE: [PATCH 2/2] iommu/ipmmu-vmsa: Add support for R-Car Gen4
@ 2022-02-03  6:54           ` Yoshihiro Shimoda
  0 siblings, 0 replies; 22+ messages in thread
From: Yoshihiro Shimoda @ 2022-02-03  6:54 UTC (permalink / raw)
  To: Geert Uytterhoeven
  Cc: open list:OPEN FIRMWARE AND FLATTENED DEVICE TREE BINDINGS,
	Linux-Renesas, Linux IOMMU, Rob Herring, Will Deacon

Hi Geert-san,

> From: Geert Uytterhoeven, Sent: Wednesday, February 2, 2022 8:07 PM
> 
> Hi Shimoda-san,
> 
> On Wed, Feb 2, 2022 at 11:48 AM Yoshihiro Shimoda
> <yoshihiro.shimoda.uh@renesas.com> wrote:
> > > From: Geert Uytterhoeven, Sent: Wednesday, February 2, 2022 6:24 PM
> > > On Tue, Jan 25, 2022 at 6:36 PM Yoshihiro Shimoda
> > > <yoshihiro.shimoda.uh@renesas.com> wrote:
> > > > Add support for R-Car Gen4 like r8a779f0 (R-Car S4-8). The IPMMU
> > > > hardware design of r8a779f0 is the same as r8a779a0. So, rename
> > > > "r8a779a0" to "rcar_gen4".
> > > >
> > > > Signed-off-by: Yoshihiro Shimoda <yoshihiro.shimoda.uh@renesas.com>
> > >
> > > Thanks for your patch!
> > >
> > > > --- a/drivers/iommu/ipmmu-vmsa.c
> > > > +++ b/drivers/iommu/ipmmu-vmsa.c
> > >
> > > > @@ -743,7 +744,7 @@ static bool ipmmu_device_is_allowed(struct device *dev)
> > > >         unsigned int i;
> > > >
> > > >         /*
> > > > -        * R-Car Gen3 and RZ/G2 use the allow list to opt-in devices.
> > > > +        * R-Car Gen3, Gen4 and RZ/G2 use the allow list to opt-in devices.
> > > >          * For Other SoCs, this returns true anyway.
> > > >          */
> > > >         if (!soc_device_match(soc_needs_opt_in))
> > >
> > > There are a few more references to "Gen3" that can be extended.
> >
> > I'm afraid, but I could not understand this mean.
> 
> I'm sorry. I mean comments that currently say "Gen3", while they are
> applicable to R-Car Gen4, too. I think it would be good to update them
> to "Gen3/4".

Thank you. I understood it. So, I'll fix it in v2.

Best regards,
Yoshihiro Shimoda

> Gr{oetje,eeting}s,
> 
>                         Geert
> 
> --
> Geert Uytterhoeven -- There's lots of Linux beyond ia32 -- geert@linux-m68k.org
> 
> In personal conversations with technical people, I call myself a hacker. But
> when I'm talking to journalists I just say "programmer" or something like that.
>                                 -- Linus Torvalds
_______________________________________________
iommu mailing list
iommu@lists.linux-foundation.org
https://lists.linuxfoundation.org/mailman/listinfo/iommu

^ permalink raw reply	[flat|nested] 22+ messages in thread

end of thread, other threads:[~2022-02-03  6:54 UTC | newest]

Thread overview: 22+ messages (download: mbox.gz / follow: Atom feed)
-- links below jump to the message on this page --
2022-01-25 12:56 [PATCH 0/2] iommu/ipmmu-vmsa: Add support for R-Car Gen4 Yoshihiro Shimoda
2022-01-25 12:56 ` Yoshihiro Shimoda
2022-01-25 12:56 ` [PATCH 1/2] dt-bindings: iommu: renesas, ipmmu-vmsa: add r8a779f0 support Yoshihiro Shimoda
2022-01-25 12:56   ` [PATCH 1/2] dt-bindings: iommu: renesas,ipmmu-vmsa: " Yoshihiro Shimoda
2022-01-27 11:05   ` Geert Uytterhoeven
2022-01-27 11:05     ` [PATCH 1/2] dt-bindings: iommu: renesas, ipmmu-vmsa: " Geert Uytterhoeven
2022-01-27 13:43     ` [PATCH 1/2] dt-bindings: iommu: renesas,ipmmu-vmsa: " Laurent Pinchart
2022-01-27 13:43       ` [PATCH 1/2] dt-bindings: iommu: renesas, ipmmu-vmsa: " Laurent Pinchart
2022-01-28  0:09     ` [PATCH 1/2] dt-bindings: iommu: renesas,ipmmu-vmsa: " Yoshihiro Shimoda
2022-01-28  0:09       ` [PATCH 1/2] dt-bindings: iommu: renesas, ipmmu-vmsa: " Yoshihiro Shimoda
2022-02-02  9:36       ` [PATCH 1/2] dt-bindings: iommu: renesas,ipmmu-vmsa: " Geert Uytterhoeven
2022-02-02  9:36         ` [PATCH 1/2] dt-bindings: iommu: renesas, ipmmu-vmsa: " Geert Uytterhoeven
2022-01-25 12:56 ` [PATCH 2/2] iommu/ipmmu-vmsa: Add support for R-Car Gen4 Yoshihiro Shimoda
2022-01-25 12:56   ` Yoshihiro Shimoda
2022-02-02  9:23   ` Geert Uytterhoeven
2022-02-02  9:23     ` Geert Uytterhoeven
2022-02-02 10:48     ` Yoshihiro Shimoda
2022-02-02 10:48       ` Yoshihiro Shimoda
2022-02-02 11:07       ` Geert Uytterhoeven
2022-02-02 11:07         ` Geert Uytterhoeven
2022-02-03  6:54         ` Yoshihiro Shimoda
2022-02-03  6:54           ` Yoshihiro Shimoda

This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.